Each of hydra-zen's :ref:`config-creation functions <create-config>` has a 
`zen_dataclass` parameter, which exposes the full API for affecting the resulting 
dataclass' properties, as exposed by :py:func:`dataclasses.make_dataclass`.

The following documentation details the available zen-dataclass options and shows 
example use cases.

.. _zen-dataclass:

hydra\_zen.typing.DataclassOptions
==================================

.. currentmodule:: hydra_zen.typing

.. autoclass:: DataclassOptions

